@@ -42,6 +42,7 @@ pub enum Command {
     Var([String; 2]),
     Change(String, Var, Math),
     Delete(String),
+    Cus(String,Vec<Var>),
 }
 #[derive(Clone)]
 pub struct Parse {
@@ -78,7 +79,7 @@ pub fn parser(code: lexer::Coder) -> Parse {
     let mut modif = 0;
     // unified panic in the main parser
     fn unif_pan(a: TT){
-        panic!(format!("MP command not found {:#?}", a))
+        panic!("MP command not found {:#?}", a)
     }
 
     for line in 0..code.lex.clone().len() {
@@ -143,6 +144,10 @@ pub fn sub_parser(pos: [usize; 2], code: lexer::Coder) -> Command {
                     TT::WhiteSpace => {
                         com.push(" ".to_string());
                     }
+                    TT::Num (a) =>{
+                        com.push(a);
+
+                    }
                     _ => panic!("sub parsing error "),
                 }
             }
@@ -184,7 +189,7 @@ pub fn sub_parser(pos: [usize; 2], code: lexer::Coder) -> Command {
                             TT::Char(a) => {
                                 args.push(a);
                             }
-                            a => panic!(format!("sub parsing error 2: {:#?}", a)),
+                            a => panic!("sub parsing error 2: {:#?}", a),
                         }
                     }
                     let args = args.join("");
@@ -234,7 +239,7 @@ pub fn sub_parser(pos: [usize; 2], code: lexer::Coder) -> Command {
                             TT::Quotation => {
                                 push_to_val = true;
                             }
-                            a => panic!(format!("sub parsing error 2: {:#?}", a)),
+                            a => panic!("sub parsing error 2: {:#?}", a),
                         }
                     }
 
@@ -295,11 +300,21 @@ pub fn sub_parser(pos: [usize; 2], code: lexer::Coder) -> Command {
                 a => {
                     //println!();
 
-                    panic!(format!("command not found {}", a))
+                    //panic!(format!("command not found {}", a))
+                    let cus = collect_str([code.next(TT::RParen, pos[0]) + 1, pos[1]], code);
+                    let cus: Vec<String> = cus.split(",<").collect::<Vec<&str>>().into_iter().map(|x|x.to_string()).collect();
+                    let mut custom_arg:  Vec<Var> = Vec::new();
+                    for x in cus{
+                        custom_arg.push(parse_str_var(x));
+                    }
+                    //println!("{:#?}",custom_arg);
+
+                    command_return = Command::Cus(a.to_string(),custom_arg)
+
                 }
             }
         }
-        a => panic!(format!("SP command not found {:#?} line {}", a, curlin)),
+        a => panic!("SP command not found {:#?} line {}", a, curlin),
     }
     //curlin += 1;
 
@@ -351,7 +366,7 @@ fn collect_str(pos: [usize; 2], code: lexer::Coder) -> String {
             TT::Quotation => {
                 args.push(r#"""#.to_string());
             }
-            a => panic!(format!("sub_ parsing error 1: {:#?}", a)),
+            a => panic!("sub_ parsing error 1: {:#?}", a),
         }
     }
     args.join("")
@@ -427,7 +442,7 @@ fn var_par(pos: [usize; 2], code: lexer::Coder) -> Command {
                 } else {
                 }
             }
-            a => panic!(format!("sub parsing error 2: {:#?}", a)),
+            a => panic!("sub parsing error 2: {:#?}", a),
         }
     }
     // it just returns Command::Change instead
